==> cms-db_v0.6.1.tar.gz: index.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

/* Check if the cms is properly installed */
if (!file_exists('./data/version.txt')) {
	include('./admin/checkphp.inc.php');
	echo '<html>
	<head>
		<title>cms -db</title>
	</head>
	<body>
		<p>
			You have to set up the CMS first!<br>
			<a href="./admin/login.php?locale=en">go to the Installation Assistant</a>
		</p>
		<p>
			Sie m&uuml;ssen das CMS zuerst einrichten!<br>
			<a href="./admin/login.php?locale=de">zum Installationsassistent</a>
		</p>
	</body>
</html>';
	die();
}

$time_start = microtime(true);

header('X-Powered-By: cms -db [http://cms-db.de/]');
header('X-Sucks: array( MSIE, Fenster );');
if (stripos($_SERVER['HTTP_ACCEPT'], 'application/xhtml+xml') !== false) {
	header('Content-type: application/xhtml+xml');
} else {
	header('Content-type: text/html');
}

/* Get the needed information out of the query string */
$query_string = urldecode($_SERVER['QUERY_STRING']);
$query_string = explode('/', $query_string, 2);
$query_string_data = $query_string[1];
$file_raw = $query_string[0];

$functions_url_website = true;
include('functions_url.inc.php');
include('./data/settings/url.inc.php');
if ($file_raw != '') {
	/* Try to get the filename form the short url */
	$filename = get_filename_from_url($file_raw);
	/* Check if the filename was found */
	if ($filename != false) {
		/* If yes, set the filename */
		$file_raw = $filename;
	} else {
		/* Prevent the url being processed as filename */
		$file_raw = '';
	}
} elseif ($query_string_data == '') {
	$file_raw = '/01,Home/01,Home';
}

$file = './data/pages'.$file_raw;

$splitfile = explode('/', $file_raw);
$count = count($splitfile);
$sec = $splitfile[1];
$sub = $splitfile[$count-1];

include('./data/settings/locale.inc.php');
chdir('./admin');
include('locale.inc.php');
chdir('../');

include('./data/settings/common.inc.php');

include('functions.inc.php');

if ($_GET['special'] != 'search') {
	$FullTitle = '';
	$title_temp = substr($file, 13);
	$title = explode('/', $title_temp);
	$first = 1;
	foreach($title as $text) {
		if ($first == 0) {
			$FullTitle .= ' &gt; ';
		}
		if ($text == '01,Home') {
			$text = $home;
		} else {
			$text = substr($text, 3);
			$text = str_replace('_', ' ',$text);
			$text = str_replace('SLASH', '/',$text);
			$text = str_replace('AND', '&amp;',$text);
		}
		$FullTitle .= $text;
		$first = 0;
	}
	if ($file_raw == '/01,Home/01,Home') {
		$PageTitle = htmlentities($home);
	} else {
		if ($sub == '01,Home') {
			$PageTitle = substr($splitfile[$count-2], 3);
		} else {
			$PageTitle = substr($sub, 3);
		}
		$PageTitle = str_replace('_', ' ', $PageTitle);
		$PageTitle = str_replace('SLASH', '/', $PageTitle);
		$PageTitle = str_replace('AND', '&amp;', $PageTitle);
		$PageTitle = str_replace('.DEL', '', $PageTitle);
	}
	$FullTitle = str_replace(' &gt; '.$home, '', $FullTitle);
	$FullTitle = str_replace('.DEL', '', $FullTitle);
} else {
	chdir('./admin');
	$locale = new LocalizingClass('frontend', $locale_default);
	chdir('../');
	$FullTitle = locale('title_search',true);
	$PageTitle = locale('title_search',true);
	unset($locale);
}


if ($_GET['special'] != 'search') {
	if (file_exists($file) && is_file($file)) {
		$PageContent = file_get_contents($file);
	} else {
		@header('HTTP/1.0 404 Not Found');
		chdir('./admin');
		$locale = new LocalizingClass('frontend', $locale_default);
		chdir('../');
		$PageTitle = locale('title_404',true);
		$FullTitle = locale('title_404',true);
		$PageContent = '<p>'.locale('desc_404',true).'</p><p>'.locale('desc_404-sitemap',true).'</p>%%SITEMAP%%';
		unset($locale);
		$sec = '';
		$sub = '';
	}
} else {
	chdir('./admin');
	$locale = new LocalizingClass('frontend', $locale_default);
	chdir('../');
	$PageContent = doSearch($_GET['q']);
	unset($locale);
	$sec = '';
	$sub = '';
}

function doInclude($inc) {
	if(file_exists('./data/includes/'.$inc)) {
		ob_start();
		include('./data/includes/'.$inc);
		$Include = ob_get_contents();
		ob_end_clean();
	} else {
		$Include = '<b>ERROR: Couldn\'t find include file "'.$inc.'"!</b>';
	}
	return $Include;
}
function doRedirect($match) {
	header('HTTP/1.1 301 Moved Permanently');
	header('Location: '.$match[1]);
}

//START TEMPLATE

include('template.class.php');

$template = new template('./data/template.tpl');

$template->readtemplate();

$template->makeIncludes();
if ($template->hasToBeReplaced('PAGECONTENT')) {
	$template->replace('PAGECONTENT', $PageContent);
}
$template->makeRedirects();
$template->makeIncludes();
$template->addToHead('<link rel="stylesheet" type="text/css" href="'.$urlabsolute.'/admin/wymeditor/style.css" media="all" />');
$template->addToHead('<meta name="generator" content="cms -db" />');
if ($hinweis == 'on') {
	$template->addBefore('</body>','<div id="cms-hinweis" style="text-align: center; font-size: 0.8em; font-family: Arial, Helvetica, sans serif; margin-top: 20px"><a href="http://cms-db.de/">Powered by <span style="color: #000000; font-family: FreeMono,Courier,monospace">cms </span><span style="color: #ff0000; font-family: FreeMono,Courier,monospace">-db</span></a></div>'."\n\n");
} else {
	$template->addBefore('</body>','<!--Powered by cms -db (http://cms-db.de/)-->'."\n\n");
}
if ($template->hasToBeReplaced('COMPLETESUBMENU')) {
	if ($sec != '') {
		$CompleteSubMenu = createCompleteMenu($urlbefore, $urlafter, './data/pages/'.$sec, $sec, $sub);
	} else {
		$CompleteSubMenu = '';
	}
	$template->replace('COMPLETESUBMENU', $CompleteSubMenu);
}
if ($template->hasToBeReplaced('FOLDINGSUBMENU')) {
	if ($sec != '') {
		$FoldingSubMenu = createFoldingMenu($urlbefore, $urlafter, './data/pages/'.$sec, $sec, $sub, $sub);
	} else {
		$FoldingSubMenu = '';
	}
	$template->replace('FOLDINGSUBMENU', $FoldingSubMenu);
}
if ($template->hasToBeReplaced('TOPMENU')) {
	$TopMenu = createTopMenu($urlbefore, $urlafter, $sec, $sub, $file);
	$template->replace('TOPMENU', $TopMenu);
}
if ($template->hasToBeReplaced('COMPLETEMENU')) {
	$CompleteMenu = createCompleteMenu($urlbefore, $urlafter, './data/pages', $sec, $sub);
	$template->replace('COMPLETEMENU', $CompleteMenu);
}
if ($template->hasToBeReplaced('FOLDINGMENU')) {
	$FoldingMenu = createFoldingMenu($urlbefore, $urlafter, './data/pages', $sec, $sub, $sec);
	$template->replace('FOLDINGMENU', $FoldingMenu);
}
if ($template->hasToBeReplaced('PAGETITLE')) {
	$template->replace('PAGETITLE', $PageTitle);
}
if ($template->hasToBeReplaced('FULLTITLE')) {
	$template->replace('FULLTITLE', $FullTitle);
}
if ($template->hasToBeReplaced('PAGESEARCH')) {
	chdir('./admin');
	$locale = new LocalizingClass('frontend', $locale_default);
	chdir('../');
	$template->replace('PAGESEARCH', '<form action="'.$urlabsolute.'/index.php" method="get">
	<div>
		<input type="hidden" name="special" value="search" />
		<input type="text" name="q" value="" size="10" maxlength="99" />
		<input type="submit" value="'.locale('button_search',true).'" />
	</div>
</form>');
	unset($locale);
}
if ($template->hasToBeReplaced('LOGINFORM')) {
	$LoginForm = LoginForm();
	$template->replace_regex('/<p>(\s*)%%LOGINFORM%%(\s*)<\/p>/U', '%%LOGINFORM%%');
	$template->replace('LOGINFORM', $LoginForm);
	$template->addToHead('<style type="text/css">/* <![CDATA[ */ #cms-db_login input { margin: 0 0 0.3em 0 } /* ]]> */</style>');
}
if ($template->hasToBeReplaced('LASTEDIT')) {
	$LastEdit = LastEdit();
	$template->replace('LASTEDIT', $LastEdit);
}
if ($template->hasToBeReplaced('PAGECOUNT')) {
	$PageCount = PageCount($file);
	$template->replace('PAGECOUNT', $PageCount);
}
if ($template->hasToBeReplaced('SITEMAP')) {
	$Sitemap = createSitemap($urlbefore, $urlafter, './data/pages');
	$template->replace_regex('/<p>(\s*)%%SITEMAP%%(\s*)<\/p>/U', '%%SITEMAP%%');
	$template->replace('SITEMAP', $Sitemap);
}
if ($template->hasToBeReplaced('SECTIONLIST')) {
	$SectionList = SectionList();
	$template->replace_regex('/<p>(\s*)%%SECTIONLIST%%(\s*)<\/p>/U', '%%SECTIONLIST%%');
	$template->replace('SECTIONLIST', $SectionList);
}
if ($template->hasToBeReplaced('URLBEFORE')) {
	$template->replace('URLBEFORE', $urlbefore);
}
if ($template->hasToBeReplaced('URLAFTER')) {
	$template->replace('URLAFTER', $urlafter);
}
if ($template->hasToBeReplaced('URLABSOLUTE')) {
	$template->replace('URLABSOLUTE', $urlabsolute);
}
if ($template->hasToBeReplaced('GUESTBOOK')) {
	ob_start();
	include('gb.php');
	$GuestBook = ob_get_contents();
	ob_end_clean();
	$template->replace_regex('/<p>(\s*)%%GUESTBOOK%%(\s*)<\/p>/U', '%%GUESTBOOK%%');
	$template->replace('GUESTBOOK', $GuestBook);
	$template->addToHead('<style type="text/css">/* <![CDATA[ */ .input_special { display: none } /* ]]> */</style>');
}

$template->parse();

//ENDE TEMPLATE

//START STATISTIK
$ip = $_SERVER['REMOTE_ADDR'];
$ip_file = './data/stats/ip.list';
if (file_exists($ip_file)) { $ip_content = file_get_contents($ip_file); } else { $ip_content = ''; }
$ip_pos = strpos($ip_content, $ip);
if ($ip_pos === false) {
	include('detect-browser.php');
	if ($os != 'BOT') {
		$os_file = str_replace(' ', '-', $os);
		$os_file = strtolower($os_file);
		$os_file = './data/stats/os/'.$os_file;
		if (file_exists($os_file)) { $os_content = file_get_contents($os_file); } else { $os_content = 'NONE'; }  
		$os_handle = fopen($os_file, 'w+');
		if ($os_content != 'NONE') {
			$os_content = explode("\n", $os_content);
			$os_count = $os_content[1] + 1;
			fwrite($os_handle, $os_content[0]."\n".$os_count);
		} else {
			fwrite($os_handle, $os."\n1");
		}
		fclose($os_handle);
	}
	$browser_file = str_replace(array(' ', "\n"), '-', $browser);
	$browser_file = strtolower($browser_file);
	$browser_file = './data/stats/browser/'.$browser_file;
	if (file_exists($browser_file)) { $browser_content = file_get_contents($browser_file); } else { $browser_content = 'NONE'; }
	$browser_handle = fopen($browser_file, "w+");
	if ($browser_content != 'NONE') {
		$browser_content = explode("\n", $browser_content);
		$browser_count = $browser_content[2] + 1;
		fwrite($browser_handle, $browser_content[0]."\n".$browser_content[1]."\n".$browser_count);
	} else {
		fwrite($browser_handle, $browser."\n1");
	}
	fclose($browser_handle);
	$ip_handle = fopen($ip_file, "a+");
	fwrite($ip_handle, $ip."\n");
	fclose($ip_handle);
}
//ENDE STATISTIK


$time_end = microtime(true);
$time = $time_end - $time_start;
echo "\n".'<!-- Parsed in '.$time.' seconds -->';
?>

==> cms-db_v0.7.5.tar.gz: index.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

/* Check if the cms is properly installed */
if (!file_exists('./data/version.txt')) {
	include('./admin/checkphp.inc.php');
	echo '<html>
	<head>
		<title>cms -db</title>
	</head>
	<body>
		<p>
			You have to set up the CMS first!<br>
			<a href="./admin/login.php?locale=en">go to the Installation Assistant</a>
		</p>
		<p>
			Sie m&uuml;ssen das CMS zuerst einrichten!<br>
			<a href="./admin/login.php?locale=de">zum Installationsassistent</a>
		</p>
	</body>
</html>';
	die();
}

$time_start = microtime(true);

include('./data/settings/common.inc.php');

header('X-Powered-By: cms -db [http://cms-db.de/]');
header('X-Sucks: array( MSIE, Fenster );');
// Blocking xhtml for d1-online.com because of bad compression
if ($xhtml == 'on'
 && stripos($_SERVER['HTTP_ACCEPT'], 'application/xhtml+xml') !== false
 && strpos($_SERVER['REMOTE_HOST'], 'd1-online.com') === false) {
	header('Content-type: application/xhtml+xml');
} else {
	header('Content-type: text/html');
}

if (extension_loaded('mbstring')) {
	mb_internal_encoding('UTF-8');
	if (function_exists('mb_regex_encoding')) {
		mb_regex_encoding('UTF-8');
	}
	function _stripos($haystack, $needle) { return mb_stripos($haystack, $needle); }
	function _substr($str, $start, $length = false) { if ($length === false) { return mb_substr($str, $start); } else { return mb_substr($str, $start, $length); } }
	function _strlen($str) { return mb_strlen($str); }
	function _eregi_replace($pattern, $replace, $string) { return mb_eregi_replace($pattern, $replace, $string); }
} else {
	function _stripos($haystack, $needle) { return stripos($haystack, $needle); }
	function _substr($str, $start, $length = false) { if ($length === false) { return substr($str, $start); } else { return substr($str, $start, $length); } }
	function _strlen($str) { return strlen($str); }
	function _eregi_replace($pattern, $replace, $string) { return eregi_replace($pattern, $replace, $string); }
}

/* Get the needed information out of the query string */
$query_string = urldecode($_SERVER['QUERY_STRING']);
$query_string = explode('/', $query_string, 2);
$query_string_data = $query_string[1];
$file_raw = $query_string[0];
$current_page = $file_raw;

$functions_url_website = true;
include('functions_url.inc.php');
include('./data/settings/url.inc.php');
if ($file_raw != '') {
	/* Try to get the filename form the short url */
	$filename = get_filename_from_url($file_raw);
	/* Check if the filename was found */
	if ($filename != false) {
		/* If yes, set the filename */
		$file_raw = $filename;
	} else {
		/* Prevent the url being processed as filename */
		$file_raw = '';
	}
} elseif ($query_string_data == '') {
	$file_raw = '/01,Home/01,Home';
	$current_page = 'home';
}

$file = './data/pages'.$file_raw;

$splitfile = explode('/', $file_raw);
$count = count($splitfile);
$sec = $splitfile[1];
$sub = $splitfile[$count-1];

include('./data/settings/locale.inc.php');
include('./admin/locale.inc.php');

include('functions.inc.php');

if ($_GET['special'] != 'search') {
	$FullTitle = '';
	$title_temp = substr($file, 13);
	$title = explode('/', $title_temp);
	$first = 1;
	foreach($title as $text) {
		if ($first == 0) {
			$FullTitle .= ' &gt; ';
		}
		if ($text == '01,Home') {
			$text = $home;
		} else {
			$text = substr($text, 3);
			$text = str_replace('_', ' ',$text);
			$text = str_replace('SLASH', '/',$text);
			$text = str_replace('AND', '&amp;',$text);
		}
		$FullTitle .= $text;
		$first = 0;
	}
	if ($file_raw == '/01,Home/01,Home') {
		$PageTitle = htmlentities($home);
	} else {
		if ($sub == '01,Home') {
			$PageTitle = substr($splitfile[$count-2], 3);
		} else {
			$PageTitle = substr($sub, 3);
		}
		$PageTitle = str_replace('_', ' ', $PageTitle);
		$PageTitle = str_replace('SLASH', '/', $PageTitle);
		$PageTitle = str_replace('AND', '&amp;', $PageTitle);
		$PageTitle = str_replace('.DEL', '', $PageTitle);
	}
	$FullTitle = str_replace(' &gt; '.$home, '', $FullTitle);
	$FullTitle = str_replace('.DEL', '', $FullTitle);
} else {
	chdir('./admin');
	$locale = new LocalizingClass('frontend', $locale_default);
	chdir('../');
	$FullTitle = locale('title_search',true);
	$PageTitle = locale('title_search',true);
	unset($locale);
}

if ($_GET['special'] != 'search') {
	if (file_exists($file) && is_file($file)) {
		$PageContent = file_get_contents($file);
	} else {
		@header('HTTP/1.0 404 Not Found');
		chdir('./admin');
		$locale = new LocalizingClass('frontend', $locale_default);
		chdir('../');
		$PageTitle = locale('title_404',true);
		$FullTitle = locale('title_404',true);
		$PageContent = '<p>'.locale('desc_404',true).'</p><p>'.locale('desc_404-sitemap',true).'</p>%%SITEMAP%%';
		unset($locale);
		$sec = '';
		$sub = '';
	}
} else {
	$lang = (isset($_GET['lang'])) ? $_GET['lang'] : $locale_default;
	chdir('./admin');
	$locale = new LocalizingClass('frontend', $lang);
	chdir('../');
	$PageContent = doSearch($_GET['q']);
	unset($locale);
	$sec = '';
	$sub = '';
}

//START TEMPLATE

include('template.class.php');

$template = new template('./data/template.tpl');

$template->replace_raw('\%', '&#37;');
$template->makeIncludes('INCLUDE');
if ($template->hasToBeReplaced('PAGECONTENT')) {
	$template->replace('PAGECONTENT', $PageContent);
}
if ($template->hasToBeReplacedStart('CONDITION')) {
	$matches = $template->matchAll('/<p>%%CONDITION-(.*)%%<\/p>(.*)<p>%%ENDCONDITION%%<\/p>/U');
	for ($foo = 0; $foo < count($matches[1]); $foo++) {
		$condition = $matches[1][$foo];
		$condition = '$val = '.$condition.';';
		eval($condition);
		if ($val) {
			$replace = $matches[2][$foo];
		} else {
			$replace = '';
		}
		$template->replace_raw($matches[0][$foo], $replace);
	}
}
$template->replace_raw('\%', '&#37;');
$template->makeIncludes('INCLUDE');
$template->replace_raw('\%', '&#37;');
$template->setLanguage();
$template->addToHead('<link rel="stylesheet" type="text/css" href="'.$urlabsolute.'/admin/wymeditor/style.css" media="all" />');
$template->addToHead('<script type="text/javascript" src="'.$urlabsolute.'/admin/wymeditor/scripts.js"></script>');
$template->addToHead('<meta name="generator" content="cms -db" />');
if ($hinweis == 'on') {
	$template->addBefore('</body>','<div id="cms-hinweis" style="text-align: center; font-size: 0.8em; font-family: Arial, Helvetica, sans serif; margin-top: 20px"><a href="http://cms-db.de/">Powered by cms -db</a></div>'."\n\n");
} else {
	$template->addBefore('</body>','<!--Powered by cms -db (http://cms-db.de/)-->'."\n\n");
}
if ($template->hasToBeReplaced('COMPLETESUBMENU')) {
	if ($sec != '') {
		$CompleteSubMenu = getCached('pages_completesubmenu', 'createCompleteMenu', array('./data/pages/'.$sec, $sec, $sub));
	} else {
		$CompleteSubMenu = '';
	}
	$template->replace('COMPLETESUBMENU', $CompleteSubMenu);
}
if ($template->hasToBeReplaced('FOLDINGSUBMENU')) {
	if ($sec != '') {
		$FoldingSubMenu = getCached('pages_foldingsubmenu', 'createFoldingMenu', array('./data/pages/'.$sec, $sec, $sub, $sub));
	} else {
		$FoldingSubMenu = '';
	}
	$template->replace('FOLDINGSUBMENU', $FoldingSubMenu);
}
if ($template->hasToBeReplaced('TOPMENU')) {
	$TopMenu = getCached('pages_topmenu', 'createTopMenu', array($sec, $file));
	$template->replace('TOPMENU', $TopMenu);
}
if ($template->hasToBeReplaced('COMPLETEMENU')) {
	$CompleteMenu = getCached('pages_completemenu', 'createCompleteMenu', array('./data/pages', $sec, $sub));
	$template->replace('COMPLETEMENU', $CompleteMenu);
}
if ($template->hasToBeReplaced('FOLDINGMENU')) {
	$FoldingMenu = getCached('pages_foldingmenu', 'createFoldingMenu', array('./data/pages', $sec, $sub, $sec));
	$template->replace('FOLDINGMENU', $FoldingMenu);
}
if ($template->hasToBeReplaced('PAGETITLE')) {
	$template->replace('PAGETITLE', $PageTitle);
}
if ($template->hasToBeReplaced('FULLTITLE')) {
	$template->replace('FULLTITLE', $FullTitle);
}
if ($template->hasToBeReplaced('BREADCRUMBS')) {
	if ($_GET['special'] != 'search') {
		$BreadCrumbs = getCached('pages_breadcrumbs', 'getBreadCrumbs', array());
	} else {
		$BreadCrumbs = $FullTitle;
	}
	$template->replace('BREADCRUMBS', $BreadCrumbs);
}
if ($template->hasToBeReplaced('PAGESEARCH')) {
	chdir('./admin');
	$locale = new LocalizingClass('frontend', $locale_default);
	chdir('../');
	$template->replace('PAGESEARCH', '<form action="'.$urlabsolute.'/index.php" method="get">
	<div>
		<input type="hidden" name="special" value="search" />
		<input type="text" name="q" value="" size="10" maxlength="99" />
		<input type="submit" value="'.locale('button_search',true).'" />
	</div>
</form>');
	unset($locale);
}
if ($template->hasToBeReplaced('LOGINFORM')) {
	$LoginForm = LoginForm();
	$template->replace_regex('/<p>(\s*)%%LOGINFORM%%(\s*)<\/p>/U', '%%LOGINFORM%%');
	$template->replace('LOGINFORM', $LoginForm);
	$template->addToHead('<style type="text/css">/* <![CDATA[ */ #cms-db_login input { margin: 0 0 0.3em 0 } /* ]]> */</style>');
}
if ($template->hasToBeReplaced('LASTEDIT')) {
	$LastEdit = LastEdit();
	$template->replace('LASTEDIT', $LastEdit);
}
if ($template->hasToBeReplaced('PAGECOUNT')) {
	$PageCount = PageCount();
	$template->replace('PAGECOUNT', $PageCount);
}
if ($template->hasToBeReplaced('SITEMAP')) {
	$Sitemap = getCached('pages_sitemap', 'createSitemap', array('./data/pages'));
	$template->replace_regex('/<p>(\s*)%%SITEMAP%%(\s*)<\/p>/U', '%%SITEMAP%%');
	$template->replace('SITEMAP', $Sitemap);
}
if ($template->hasToBeReplaced('SECTIONLIST')) {
	$SectionList = getCached('pages_sectionlist', 'SectionList', array());
	$template->replace_regex('/<p>(\s*)%%SECTIONLIST%%(\s*)<\/p>/U', '%%SECTIONLIST%%');
	$template->replace('SECTIONLIST', $SectionList);
}
if ($template->hasToBeReplacedStart('TAGCLOUD')) {
	$matches = $template->matchAll('/%%TAGCLOUD-(.*)%%/U');
	for ($foo = 0; $foo < count($matches[1]); $foo++) {
		$blogurl = $matches[1][$foo];
		$TagCloud = getCached('blog_tagcloud', 'TagCloud', array($blogurl), $blogurl);
		$template->replace_raw($matches[0][$foo], $TagCloud);
	}
}
if ($template->hasToBeReplacedStart('LATESTBLOGARTICLES')) {
	$template->replace_regex('/<p>(\s*)%%LATESTBLOGARTICLES-(.*)%%(\s*)<\/p>/U', '%%LATESTBLOGARTICLES-$2%%');
	$matches = $template->matchAll('/%%LATESTBLOGARTICLES-(.*)%%/U');
	for ($foo = 0; $foo < count($matches[1]); $foo++) {
		$blogurl = $matches[1][$foo];
		$LatestBlogArticles = getCached('blog_latestblogarticles', 'LatestBlogArticles', array($blogurl), $blogurl);
		$template->replace_raw($matches[0][$foo], $LatestBlogArticles);
	}
}
if ($template->hasToBeReplaced('URLBEFORE')) {
	$template->replace('URLBEFORE', $urlbefore);
}
if ($template->hasToBeReplaced('URLAFTER')) {
	$template->replace('URLAFTER', $urlafter);
}
if ($template->hasToBeReplaced('URLABSOLUTE')) {
	$template->replace('URLABSOLUTE', $urlabsolute);
}
if ($template->hasToBeReplacedStart('MAILFORM')) {
	$template->replace_regex('/<p>(\s*)%%MAILFORM-(.*)%%(\s*)<\/p>/U', '%%MAILFORM-$2%%');
	$matches = $template->matchAll('/%%MAILFORM-(.*)%%/U');
	for ($foo = 0; $foo < count($matches[1]); $foo++) {
		$mailaddress = $matches[1][$foo];
		ob_start();
		include('contact.php');
		$MailForm = ob_get_contents();
		ob_end_clean();
		$template->replace_raw($matches[0][$foo], $MailForm);
	}
}
$template->makeIncludes('LATEINCLUDE');
if ($template->hasToBeReplacedStart('BLOG')) {
	$template->replace_regex('/<p>(\s*)%%BLOG-(.*)%%(\s*)<\/p>/U', '%%BLOG-$2%%');
	$matches = $template->matchAll('/%%BLOG-(.*)%%/U');
	if (count($matches[1]) > 0) {
		for ($foo = 0; $foo < count($matches[1]); $foo++) {
			$blogattr = $matches[1][$foo];
			$blogattr = explode('-', $blogattr);
			include('blog.php');
			$template->replace_raw($matches[0][$foo], $blog);
		}
	} else {
		$blogattr = array();
		include('blog.php');
		$template->replace('/<p>(\s*)%%BLOG%%(\s*)<\/p>/U', '%%BLOG%%');
		$template->replace('BLOG', $blog);
	}
} elseif ($template->hasToBeReplaced('GUESTBOOK')) {
	ob_start();
	include('gb.php');
	$GuestBook = ob_get_contents();
	ob_end_clean();
	$template->replace_regex('/<p>(\s*)%%GUESTBOOK%%(\s*)<\/p>/U', '%%GUESTBOOK%%');
	$template->replace('GUESTBOOK', $GuestBook);
}
$template->replace_raw('&#37;', '%');

$template->output();

//ENDE TEMPLATE

//START STATISTIK
$ip = $_SERVER['REMOTE_ADDR'];
$ip_file = './data/stats/ip.list';
if (file_exists($ip_file)) { $ip_content = file_get_contents($ip_file); } else { $ip_content = ''; }
$ip_pos = strpos($ip_content, $ip);
if ($ip_pos === false) {
	include('detect-browser.php');
	if ($os != 'BOT') {
		$os_file = str_replace(' ', '-', $os);
		$os_file = strtolower($os_file);
		$os_file = './data/stats/os/'.$os_file;
		if (file_exists($os_file)) { $os_content = file_get_contents($os_file); } else { $os_content = 'NONE'; }  
		$os_handle = fopen($os_file, 'w+');
		if ($os_content != 'NONE') {
			$os_content = explode("\n", $os_content);
			$os_count = $os_content[1] + 1;
			fwrite($os_handle, $os_content[0]."\n".$os_count);
		} else {
			fwrite($os_handle, $os."\n1");
		}
		fclose($os_handle);
	}
	$browser_file = str_replace(array(' ', "\n"), '-', $browser);
	$browser_file = strtolower($browser_file);
	$browser_file = './data/stats/browser/'.$browser_file;
	if (file_exists($browser_file)) { $browser_content = file_get_contents($browser_file); } else { $browser_content = 'NONE'; }
	$browser_handle = fopen($browser_file, "w+");
	if ($browser_content != 'NONE') {
		$browser_content = explode("\n", $browser_content);
		$browser_count = $browser_content[2] + 1;
		fwrite($browser_handle, $browser_content[0]."\n".$browser_content[1]."\n".$browser_count);
	} else {
		fwrite($browser_handle, $browser."\n1");
	}
	fclose($browser_handle);
	$ip_handle = fopen($ip_file, "a+");
	fwrite($ip_handle, $ip."\n");
	fclose($ip_handle);
}
//ENDE STATISTIK


$time_end = microtime(true);
$time = $time_end - $time_start;
echo "\n".'<!-- Parsed in '.$time.' seconds -->';
?>
